@@ -2,10 +2,7 @@
 import time
 import pytest
 
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 from atpbar.presentation.txtprint import ProgressPrint
 
